@@ -12,8 +12,10 @@ use XML::Simple;
 use URI::Escape;
 use AWS::Signature4;
 use HTTP::Request::Common;
+use Amazon::SNS::V4::Target;
+use Amazon::SNS::V4::Topic;
 
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 
 
 sub CreateTopic
@@ -170,6 +172,7 @@ package Amazon::SNS::V4::Topic;
 use strict;
 use warnings;
 
+our $VERSION = '1.7';
 use base qw(Class::Accessor);
 
 use JSON;
@@ -219,6 +222,7 @@ package Amazon::SNS::V4::Target;
 use strict;
 use warnings;
 
+our $VERSION = '1.7';
 use base qw(Class::Accessor);
 
 use JSON;
@@ -275,7 +279,6 @@ sub Publish
 
 1;
 
-
 =head1 NAME
 
 Amazon::SNS::V4 - Amazon Simple Notification Service with v4 Signatures
@@ -423,12 +426,15 @@ L<AWS::Signature4>
 
 =head1 COPYRIGHT AND LICENSE
 
+Copyright (C) 2020 James Wright
+
 Copyright (C) 2011-15 Alessandro Zummo
 
-Copyright (C) 2020 James Wright
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License version 2 as
 published by the Free Software Foundation.
 
+
 =cut
+
